@@ -7,7 +7,7 @@ use ElasticSearch::Error();
 use ElasticSearch::RequestParser;
 use ElasticSearch::Util qw(throw parse_params);
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 our $DEBUG   = 0;
 
 #===================================
@@ -152,7 +152,7 @@ ElasticSearch - An API for communicating with ElasticSearch
 
 =head1 VERSION
 
-Version 0.51, tested against ElasticSearch server version 0.19.0.
+Version 0.52, tested against ElasticSearch server version 0.19.0.
 
 =head1 DESCRIPTION
 
@@ -1660,8 +1660,10 @@ L</"INTEGRATION WITH ElasticSearch::SearchBuilder"> for more details.
 
     $result = $es->aliases( actions => [
         { add    => {
-            index   => 'foo',
-            alias   => 'baz',
+            index           => 'foo',
+            alias           => 'baz',
+            index_routing   => '1',
+            search_routing  => '1,2',
             filterb => { foo => 'bar' }
         }}
     ]);
@@ -1672,21 +1674,31 @@ See L<http://www.elasticsearch.org/guide/reference/api/admin-indices-aliases.htm
 
     $result = $es->get_aliases( index => multi )
 
-Returns a hashref listing all indices and their corresponding aliases, and
-all aliases and their corresponding indices, eg:
+Returns a hashref listing all indices and their corresponding aliases, eg:
 
     {
-      aliases => {
-         bar => ["foo"],
-         baz => ["foo"],
-      },
-      indices => { foo => ["baz", "bar"] },
+       "foo" : {
+          "aliases" : {
+             "foo_1" : {
+                "search_routing" : "1,2",
+                "index_routing" : "1"
+                "filter" : {
+                   "term" : {
+                      "foo" : "bar"
+                   }
+                }
+             },
+             "foo_2" : {}
+          }
+       }
     }
 
 If you pass in the optional C<index> argument, which can be an index name
-or an alias name, then it will only return the indices and aliases related
+or an alias name, then it will only return the indices related
 to that argument.
 
+See L<http://www.elasticsearch.org/guide/reference/api/admin-indices-aliases.html>
+
 =head3 open_index()
 
     $result = $es->open_index( index => single);
